@@ -1,6 +1,8 @@
 context("MCBoost PipeOp")
 
 test_that("MCBoost class instantiation", {
+  skip_on_cran()
+  skip_on_os("solaris")
   skip_if_not(require("mlr3"))
   skip_if_not(require("mlr3pipelines"))
   gr = gunion(list(
@@ -20,6 +22,8 @@ test_that("MCBoost class instantiation", {
 })
 
 test_that("MCBoost ppl", {
+  skip_on_cran()
+  skip_on_os("solaris")
   skip_if_not(require("mlr3"))
   skip_if_not(require("mlr3pipelines"))
 
